==> jc-1.4.0.tar.gz: ppg/atoms/Precedence.h <==
// public class ppg.atoms.Precedence

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 769610ab4eb104be ppg_atoms_Precedence

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_Precedence_H_
#define _JC_ppg_atoms_Precedence_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_ppg_atoms_Precedence$sub_refs	_jc_ppg_atoms_Precedence$sub_refs;
typedef struct _jc_ppg_atoms_Precedence$sub_nonrefs	_jc_ppg_atoms_Precedence$sub_nonrefs;
typedef struct _jc_ppg_atoms_Precedence$refs	_jc_ppg_atoms_Precedence$refs;
typedef struct _jc_ppg_atoms_Precedence$nonrefs	_jc_ppg_atoms_Precedence$nonrefs;
typedef struct _jc_ppg_atoms_Precedence$object	_jc_ppg_atoms_Precedence$object;

typedef struct _jc_ppg_atoms_Precedence$fields_struct	_jc_ppg_atoms_Precedence$fields_struct;
typedef const struct _jc_ppg_atoms_Precedence$vmethods	_jc_ppg_atoms_Precedence$vmethods;
typedef const struct _jc_ppg_atoms_Precedence$vtable	_jc_ppg_atoms_Precedence$vtable;
typedef const struct _jc_ppg_atoms_Precedence$vtype	_jc_ppg_atoms_Precedence$vtype;

// Class fields structure
struct _jc_ppg_atoms_Precedence$fields_struct {
	jint	LEFT;
	jint	NONASSOC;
	jint	RIGHT;
};
extern _jc_ppg_atoms_Precedence$fields_struct _jc_ppg_atoms_Precedence$class_fields;

// Constructors
extern void _jc_ppg_atoms_Precedence$method$_init$c4a0b57d466f6f07(_jc_env *, struct _jc_ppg_atoms_Precedence$object *, jint, struct _jc_java_util_Vector$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_Precedence$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_Precedence$object *);
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_Precedence$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_Precedence$object *);

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_Precedence$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_Precedence$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_atoms_Precedence$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_Precedence$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_Precedence$object *);
};

// Vtable
struct _jc_ppg_atoms_Precedence$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_Precedence$vmethods	ppg_atoms_Precedence;
};

// Vtype
struct _jc_ppg_atoms_Precedence$vtype {
	_jc_type			type;
	_jc_ppg_atoms_Precedence$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_Precedence$sub_refs {
	struct _jc_java_util_Vector$object	*symbols;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_Precedence$refs {
    _jc_ppg_atoms_Precedence$sub_refs	ppg_atoms_Precedence;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_Precedence$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_Precedence$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_Precedence$sub_nonrefs	ppg_atoms_Precedence;
};

// Object instance structure
struct _jc_ppg_atoms_Precedence$object {
	_jc_ppg_atoms_Precedence$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_Precedence$vtype	*vtype;
	_jc_ppg_atoms_Precedence$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_Precedence$vtype _jc_ppg_atoms_Precedence$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_Precedence, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_Precedence$class_object;

#endif	/* _JC_ppg_atoms_Precedence_H_ */

==> jc-1.4.6.tar.gz: ppg/atoms/Precedence.h <==
// public class ppg.atoms.Precedence

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 769610ab4eb104be ppg_atoms_Precedence

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_ppg_atoms_Precedence_H_
#define _JC_ppg_atoms_Precedence_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_ppg_atoms_Precedence$sub_refs	_jc_ppg_atoms_Precedence$sub_refs;
typedef struct _jc_ppg_atoms_Precedence$sub_nonrefs	_jc_ppg_atoms_Precedence$sub_nonrefs;
typedef struct _jc_ppg_atoms_Precedence$refs	_jc_ppg_atoms_Precedence$refs;
typedef struct _jc_ppg_atoms_Precedence$nonrefs	_jc_ppg_atoms_Precedence$nonrefs;
typedef struct _jc_ppg_atoms_Precedence$object	_jc_ppg_atoms_Precedence$object;

typedef struct _jc_ppg_atoms_Precedence$fields_struct	_jc_ppg_atoms_Precedence$fields_struct;
typedef const struct _jc_ppg_atoms_Precedence$vmethods	_jc_ppg_atoms_Precedence$vmethods;
typedef const struct _jc_ppg_atoms_Precedence$vtable	_jc_ppg_atoms_Precedence$vtable;
typedef const struct _jc_ppg_atoms_Precedence$vtype	_jc_ppg_atoms_Precedence$vtype;

// Class fields structure
struct _jc_ppg_atoms_Precedence$fields_struct {
	jint	LEFT;
	jint	NONASSOC;
	jint	RIGHT;
};
extern _jc_ppg_atoms_Precedence$fields_struct _jc_ppg_atoms_Precedence$class_fields;

// Constructors
extern void _jc_ppg_atoms_Precedence$method$_init$c4a0b57d466f6f07(_jc_env *, struct _jc_ppg_atoms_Precedence$object *, jint, struct _jc_java_util_Vector$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_ppg_atoms_Precedence$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_ppg_atoms_Precedence$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_ppg_atoms_Precedence$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_ppg_atoms_Precedence$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_ppg_atoms_Precedence$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_ppg_atoms_Precedence$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_ppg_atoms_Precedence$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_ppg_atoms_Precedence$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_ppg_atoms_Precedence$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_ppg_atoms_Precedence$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_ppg_atoms_Precedence$vmethods	ppg_atoms_Precedence;
};

// Vtype
struct _jc_ppg_atoms_Precedence$vtype {
	_jc_type			type;
	_jc_ppg_atoms_Precedence$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_ppg_atoms_Precedence$sub_refs {
	struct _jc_java_util_Vector$object	*symbols;
};

// Reference instance fields (object)
struct _jc_ppg_atoms_Precedence$refs {
    _jc_ppg_atoms_Precedence$sub_refs	ppg_atoms_Precedence;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_ppg_atoms_Precedence$sub_nonrefs {
	jint	type;
};

// Non-reference instance fields (object)
struct _jc_ppg_atoms_Precedence$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_ppg_atoms_Precedence$sub_nonrefs	ppg_atoms_Precedence;
};

// Object instance structure
struct _jc_ppg_atoms_Precedence$object {
	_jc_ppg_atoms_Precedence$refs	refs[0];
	_jc_word		lockword;
	_jc_ppg_atoms_Precedence$vtype	*vtype;
	_jc_ppg_atoms_Precedence$nonrefs	nonrefs;
};

// Type structure
extern _jc_ppg_atoms_Precedence$vtype _jc_ppg_atoms_Precedence$type;

// Array types class info structures
_JC_DECL_ARRAYS(ppg_atoms_Precedence, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_ppg_atoms_Precedence$class_object;

#endif	/* _JC_ppg_atoms_Precedence_H_ */
